from setuptools import setup

setup(
    name="quuz",
    version="0.0.1a",
    author="EclecticIQ",
    author_email="engineering@eclecticiq.com",
    url="https://github.com/eclecticiq/quuz",
    py_modules=["quuz"],
)
